@@ -19,8 +19,8 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
-	kcmdutil "k8s.io/kubernetes/pkg/kubectl/cmd/util"
-	"k8s.io/kubernetes/pkg/kubectl/util/templates"
+	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
+	"k8s.io/kubectl/pkg/util/templates"
 
 	imagev1 "github.com/openshift/api/image/v1"
 	imagev1typedclient "github.com/openshift/client-go/image/clientset/versioned/typed/image/v1"
@@ -167,7 +167,7 @@ func (o *VerifyImageSignatureOptions) Complete(f kcmdutil.Factory, cmd *cobra.Co
 	// We need the current user name so we can record it into an verification condition and
 	// we need a bearer token so we can fetch the manifest from the registry.
 	// TODO: Add support for external registries (currently only integrated registry will
-	if me, err := userClient.Users().Get("~", metav1.GetOptions{}); err != nil {
+	if me, err := userClient.Users().Get(context.TODO(), "~", metav1.GetOptions{}); err != nil {
 		return err
 	} else {
 		o.CurrentUser = me.Name
@@ -185,7 +185,7 @@ func (o *VerifyImageSignatureOptions) Complete(f kcmdutil.Factory, cmd *cobra.Co
 }
 
 func (o VerifyImageSignatureOptions) Run() error {
-	img, err := o.ImageClient.Images().Get(o.InputImage, metav1.GetOptions{})
+	img, err := o.ImageClient.Images().Get(context.TODO(), o.InputImage, metav1.GetOptions{})
 	if err != nil {
 		return err
 	}
@@ -243,7 +243,7 @@ func (o VerifyImageSignatureOptions) Run() error {
 	}
 
 	if o.Save || o.RemoveAll {
-		_, err := o.ImageClient.Images().Update(img)
+		_, err := o.ImageClient.Images().Update(context.TODO(), img, metav1.UpdateOptions{})
 		return err
 	} else {
 		fmt.Fprintf(o.Out, "Neither --save nor --remove-all were passed, image %q not updated to %v\n", o.InputImage, img)
@@ -278,7 +278,7 @@ func (o *VerifyImageSignatureOptions) verifySignature(pc *signature.PolicyContex
 	if err != nil {
 		return "", fmt.Errorf("failed to get image %q manifest: %v", img.Name, err)
 	}
-	allowed, err := pc.IsRunningImageAllowed(newUnparsedImage(o.ExpectedIdentity, sigBlob, manifest))
+	allowed, err := pc.IsRunningImageAllowed(context.TODO(), newUnparsedImage(o.ExpectedIdentity, sigBlob, manifest))
 	if !allowed && err == nil {
 		return "", errors.New("signature rejected but no error set")
 	}
@@ -394,16 +394,16 @@ func (ref dummyDockerReference) PolicyConfigurationNamespaces() []string {
 	return policyconfiguration.DockerReferenceNamespaces(ref.ref)
 }
 
-func (ref dummyDockerReference) NewImage(ctx *sigtypes.SystemContext) (sigtypes.Image, error) {
+func (ref dummyDockerReference) NewImage(context.Context, *sigtypes.SystemContext) (sigtypes.ImageCloser, error) {
 	panic("Unimplemented")
 }
-func (ref dummyDockerReference) NewImageSource(ctx *sigtypes.SystemContext, requestedManifestMIMETypes []string) (sigtypes.ImageSource, error) {
+func (ref dummyDockerReference) NewImageSource(context.Context, *sigtypes.SystemContext) (sigtypes.ImageSource, error) {
 	panic("Unimplemented")
 }
-func (ref dummyDockerReference) NewImageDestination(ctx *sigtypes.SystemContext) (sigtypes.ImageDestination, error) {
+func (ref dummyDockerReference) NewImageDestination(context.Context, *sigtypes.SystemContext) (sigtypes.ImageDestination, error) {
 	panic("Unimplemented")
 }
-func (ref dummyDockerReference) DeleteImage(ctx *sigtypes.SystemContext) error {
+func (ref dummyDockerReference) DeleteImage(context.Context, *sigtypes.SystemContext) error {
 	panic("Unimplemented")
 }
 
@@ -433,7 +433,7 @@ func (ui *unparsedImage) Close() error {
 }
 
 // Manifest is like ImageSource.GetManifest, but the result is cached; it is OK to call this however often you need.
-func (ui *unparsedImage) Manifest() ([]byte, string, error) {
+func (ui *unparsedImage) Manifest(context.Context) ([]byte, string, error) {
 	return ui.manifest, "", nil
 }
 
